You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by dl...@apache.org on 2006/04/28 03:41:48 UTC

svn commit: r397712 [2/2] - /incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/method.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/method.c?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/method.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/method.c Thu Apr 27 18:41:46 2006
@@ -88,9 +88,9 @@
  *         search result.
  *
  */
-jvm_method_index method_find_by_cp_entry(jvm_class_index  clsidx,
-                                         cp_info_dup     *mthname,
-                                         cp_info_dup     *mthdesc)
+jvm_method_index method_find_by_cp_entry(jvm_class_index    clsidx,
+                                         cp_info_mem_align *mthname,
+                                         cp_info_mem_align *mthdesc)
 {
     ARCH_FUNCTION_NAME(method_find_by_cp_entry);
 
@@ -168,8 +168,8 @@
 {
     ARCH_FUNCTION_NAME(method_find_by_prchar);
 
-    cp_info_dup *pcip_mthname = nts_prchar2utf(mthname);
-    cp_info_dup *pcip_mthdesc = nts_prchar2utf(mthdesc);
+    cp_info_mem_align *pcip_mthname = nts_prchar2utf(mthname);
+    cp_info_mem_align *pcip_mthdesc = nts_prchar2utf(mthdesc);
 
     jvm_method_index rc =
         method_find_by_cp_entry(clsidx, pcip_mthname, pcip_mthdesc);
@@ -204,20 +204,20 @@
 {
     ARCH_FUNCTION_NAME(method_return_type);
 
-    cp_info_dup        *pcpd;
-    CONSTANT_Utf8_info *pcpd_Utf8;
+    cp_info_mem_align  *pcpma;
+    CONSTANT_Utf8_info *pcpma_Utf8;
 
-    pcpd =CLASS_OBJECT_LINKAGE(clsidx)->pcfs->constant_pool[mthdescidx];
-    pcpd_Utf8 = PTR_THIS_CP_Utf8(pcpd);
+    pcpma=CLASS_OBJECT_LINKAGE(clsidx)->pcfs->constant_pool[mthdescidx];
+    pcpma_Utf8 = PTR_THIS_CP_Utf8(pcpma);
 
     u2 idx;
            /* Last char will be result:/ - 1/ except 'Lsome/class;' */
-    for(idx = 0; idx < pcpd_Utf8->length - 1; idx++)
+    for(idx = 0; idx < pcpma_Utf8->length - 1; idx++)
     {
         /* Scan for parm list closure, next char is return type */
-        if (METHOD_CHAR_CLOSE_PARM == pcpd_Utf8->bytes[idx])
+        if (METHOD_CHAR_CLOSE_PARM == pcpma_Utf8->bytes[idx])
         {
-            switch (pcpd_Utf8->bytes[idx + 1])
+            switch (pcpma_Utf8->bytes[idx + 1])
             {
                 case BASETYPE_CHAR_B:
                 case BASETYPE_CHAR_C:
@@ -230,7 +230,7 @@
                 case BASETYPE_CHAR_Z:
                 case BASETYPE_CHAR_ARRAY:
                 case METHOD_CHAR_VOID:
-                    return((jvm_basetype) pcpd_Utf8->bytes[idx + 1]);
+                    return((jvm_basetype) pcpma_Utf8->bytes[idx + 1]);
                 default:
                     /* Found something, but it was invalid */
                     return((jvm_basetype) LOCAL_BASETYPE_ERROR);
@@ -282,11 +282,11 @@
 {
     ARCH_FUNCTION_NAME(method_parm_size);
 
-    cp_info_dup        *pcpd;
-    CONSTANT_Utf8_info *pcpd_Utf8;
+    cp_info_mem_align  *pcpma;
+    CONSTANT_Utf8_info *pcpma_Utf8;
 
-    pcpd =CLASS_OBJECT_LINKAGE(clsidx)->pcfs->constant_pool[mthdescidx];
-    pcpd_Utf8 = PTR_THIS_CP_Utf8(pcpd);
+    pcpma=CLASS_OBJECT_LINKAGE(clsidx)->pcfs->constant_pool[mthdescidx];
+    pcpma_Utf8 = PTR_THIS_CP_Utf8(pcpma);
 
     rboolean find_open_paren;
     find_open_paren = rtrue;
@@ -301,12 +301,12 @@
 
     u2 idx;
            /* Last char will be result:/ - 1/ except 'Lsome/class;' */
-    for(idx = 0; idx < pcpd_Utf8->length - 1; idx++)
+    for(idx = 0; idx < pcpma_Utf8->length - 1; idx++)
     {
         /* Skip past class/path/name until closing semicolon */
         if (rtrue == find_class_close)
         {
-            if (BASETYPE_CHAR_L_TERM == pcpd_Utf8->bytes[idx])
+            if (BASETYPE_CHAR_L_TERM == pcpma_Utf8->bytes[idx])
             {
                 find_class_close = rfalse;
             }
@@ -319,7 +319,7 @@
         if (rtrue == find_open_paren)
         {
             /* If open paren found, start scanning descriptor */
-            if (METHOD_CHAR_OPEN_PARM == pcpd_Utf8->bytes[idx])
+            if (METHOD_CHAR_OPEN_PARM == pcpma_Utf8->bytes[idx])
             {
                 /*
                  * If anything precedes the open paren,
@@ -339,7 +339,7 @@
         }
 
         /* Done if close paren, being end of descriptor */
-        if (METHOD_CHAR_CLOSE_PARM == pcpd_Utf8->bytes[idx])
+        if (METHOD_CHAR_CLOSE_PARM == pcpma_Utf8->bytes[idx])
         {
             /* Something is profoundly wrong if any condition is true */
             if ((rtrue == find_open_paren) ||
@@ -356,7 +356,7 @@
         }
 
         /* Scan for parm list closure, next char is return type */
-        switch (pcpd_Utf8->bytes[idx])
+        switch (pcpma_Utf8->bytes[idx])
         {
             case BASETYPE_CHAR_B:
             case BASETYPE_CHAR_C:

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/method.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/method.h?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/method.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/method.h Thu Apr 27 18:41:46 2006
@@ -75,9 +75,9 @@
 /* Prototypes for functions in 'method.c' */
 
 extern
-    jvm_method_index method_find_by_cp_entry(jvm_class_index  clsidx,
-                                             cp_info_dup    *mthname,
-                                             cp_info_dup    *mthdesc);
+    jvm_method_index method_find_by_cp_entry(jvm_class_index   clsidx,
+                                            cp_info_mem_align *mthname,
+                                            cp_info_mem_align *mthdesc);
 
 extern jvm_method_index method_find_by_prchar(jvm_class_index  clsidx,
                                               rchar           *mthname,

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.c?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.h Thu Apr 27 18:41:46 2006
@@ -55,12 +55,12 @@
 
 /* Prototypes for functions in 'nts.c' */
 
-extern cp_info_dup *nts_prchar2utf(rchar *inbfr);
+extern cp_info_mem_align *nts_prchar2utf(rchar *inbfr);
 
 extern jshort nts_prchar2unicode(rchar *inbfr, jchar *outbfr);
 
-extern cp_info_dup *nts_prchar2utf_classname(rchar        *inbfr,
-                                             jvm_array_dim arraydims);
+extern cp_info_mem_align *nts_prchar2utf_classname(rchar    *inbfr,
+                                              jvm_array_dim  arraydims);
 
 extern jvm_array_dim nts_get_prchar_arraydims(rchar *inbfr);
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opcode.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opcode.c?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.h Thu Apr 27 18:41:46 2006
@@ -56,7 +56,7 @@
 
 /* Prototypes for functions in 'unicode.c' */
 
-extern cp_info_dup *unicode_cnv2utf(jchar *inbfr, jshort length);
+extern cp_info_mem_align *unicode_cnv2utf(jchar *inbfr, jshort length);
 
 extern jshort unicode_strcmp(jchar *us1, u2 l1, jchar *us2, u2 l2);
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.c?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.c Thu Apr 27 18:41:46 2006
@@ -886,7 +886,8 @@
  *
  */
 
-cp_info_dup *utf_utf2utf_unformatted_classname(cp_info_dup *inbfr)
+cp_info_mem_align
+    *utf_utf2utf_unformatted_classname(cp_info_mem_align *inbfr)
 {
     ARCH_FUNCTION_NAME(utf_u2f2utf_unformatted_classname);
 
@@ -896,7 +897,7 @@
 
     HEAP_FREE_DATA(pstr);
 
-    cp_info_dup *rc = nts_prchar2utf(punf);
+    cp_info_mem_align *rc = nts_prchar2utf(punf);
 
     HEAP_FREE_DATA(punf);
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.h?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/utf.h Thu Apr 27 18:41:46 2006
@@ -89,8 +89,8 @@
 
 extern rboolean utf_utf_isclassformatted(CONSTANT_Utf8_info *src);
 
-extern cp_info_dup
-                 *utf_utf2utf_unformatted_classname(cp_info_dup *inbfr);
+extern cp_info_mem_align
+           *utf_utf2utf_unformatted_classname(cp_info_mem_align *inbfr);
 
 #endif /* _utf_h_defined_ */
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.c Thu Apr 27 18:41:46 2006
@@ -66,8 +66,9 @@
  *
  *
  * @returns UTF8 structure containing length and rchar bfr (plus tag),
  *          but return in (cp_info_dup) for full proper word alignment.
  *          When done with the data, call HEAP_FREE_DATA() on it.
  *
  *    @c @b rc-\>bytes      UTF8 version of @b inbfr string
  *
@@ -75,7 +76,7 @@
  *                          @c @b rc-\>bytes
  */
 
-cp_info_dup *nts_prchar2utf(rchar *inbfr)
+cp_info_mem_align *nts_prchar2utf(rchar *inbfr)
 {
     ARCH_FUNCTION_NAME(nts_prchar2utf);
 
@@ -88,12 +89,12 @@
      * info, adjusting for the amount of string data to be stored
      * into the result.
      */
-    cp_info_dup *rc = HEAP_GET_DATA(sizeof(cp_info_dup) -
-                                        sizeof(cp_info) +
-                                        sizeof(CONSTANT_Utf8_info) -
-                                        sizeof(u1) +
-                                        len,
-                                    rfalse);
+    cp_info_mem_align *rc = HEAP_GET_DATA(sizeof(cp_info_mem_align) -
+                                              sizeof(cp_info) +
+                                            sizeof(CONSTANT_Utf8_info) -
+                                              sizeof(u1) +
+                                              len,
+                                          rfalse);
 
     /* Move (rchar *) string into (CONSTANT_Utf8_info) */
     CONSTANT_Utf8_info *pcpui = PTR_THIS_CP_Utf8(rc);
@@ -174,9 +175,9 @@
  *
  *
  * @returns UTF8 structure containing length and rchar bfr (plus tag),
  *          but return in (cp_info_dup) for full proper word alignment.
  *          When done with the data, call HEAP_FREE_DATA() on it.
  *          With @b inbfr of @c @b some/path/name/filename,
  *          the result will be, with 3 array dimensions:
  *
  * @verbatim
@@ -197,8 +198,8 @@
  *
  */
 
-cp_info_dup *nts_prchar2utf_classname(rchar         *inbfr,
-                                      jvm_array_dim  arraydims)
+cp_info_mem_align *nts_prchar2utf_classname(rchar         *inbfr,
+                                            jvm_array_dim  arraydims)
 {
     ARCH_FUNCTION_NAME(nts_prchar2utf_classname);
 
@@ -219,8 +220,8 @@
                  sizeof(u1) +     /* Type terminator */
                  sizeof(u1);      /* NUL character */
 
-    cp_info_dup *rc =
-        HEAP_GET_DATA(sizeof(cp_info_dup) -   /* Enclosing structure */
+    cp_info_mem_align *rc =
+        HEAP_GET_DATA(sizeof(cp_info_mem_align) - /* Enclosing struct */
                           sizeof(cp_info) +   /* Basic type */
                           sizeof(CONSTANT_Utf8_info) - /* UTF8 type */
                           sizeof(u1) +        /* Data place holder */
@@ -66,8 +66,9 @@
  *
  * @returns UTF8 structure containing length and rchar bfr (plus tag),
- *          but return in (cp_info_dup) for full proper word alignment.
- *          When done with the data, call HEAP_FREE_DATA() on it.
+ *          but return in (cp_info_mem_align) for full proper word
+ *          alignment. When done with the data, call HEAP_FREE_DATA()
+ *          on it.
  *
  *    @c @b rc-\>bytes      UTF8 version of @b inbfr string
@@ -174,9 +175,9 @@
  *
  * @returns UTF8 structure containing length and rchar bfr (plus tag),
- *          but return in (cp_info_dup) for full proper word alignment.
- *          When done with the data, call HEAP_FREE_DATA() on it.
- *          With @b inbfr of @c @b some/path/name/filename,
+ *          but return in (cp_info_mem_align) for full proper word
+ *          alignment. When done with the data, call HEAP_FREE_DATA()
+ *          on it. With @b inbfr of @c @b some/path/name/filename,
  *          the result will be, with 3 array dimensions:
  *

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/nts.h?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opcode.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opcode.c Thu Apr 27 18:41:46 2006
@@ -938,11 +938,11 @@
 
 
         /* Scratch area for Fieldref and Methodref navigation */
-        cp_info_dup               *pcpd;
-        CONSTANT_Class_info       *pcpd_Class;
-        CONSTANT_Fieldref_info    *pcpd_Fieldref;
-        CONSTANT_Methodref_info   *pcpd_Methodref;
-        CONSTANT_Utf8_info        *pcpd_Utf8;
+        cp_info_mem_align         *pcpma;
+        CONSTANT_Class_info       *pcpma_Class;
+        CONSTANT_Fieldref_info    *pcpma_Fieldref;
+        CONSTANT_Methodref_info   *pcpma_Methodref;
+        CONSTANT_Utf8_info        *pcpma_Utf8;
 
         field_info              *pfld;
         method_info             *pmth;
@@ -2544,7 +2544,7 @@
     /* Must reference a field */
     CHECK_CP_TAG(op1u2, CONSTANT_Fieldref);
 
     /* calc clsidxmisc and pcpd and pcpd_Fieldref */
     CALCULATE_FIELD_INFO_FROM_FIELD_REFERENCE(op1u2);
 
     /* Must be a valid reference to a field */
@@ -2566,7 +2566,7 @@
             CHECK_FINAL_FIELD_CURRENT_CLASS;
 
             /* Retrieve data from the class static field now */
-            GETDATA(CLASS(pcpd_Fieldref
+            GETDATA(CLASS(pcpma_Fieldref
                             ->LOCAL_Fieldref_binding
                               .clsidxJVM)
                       .class_static_field_data[fluidxmisc]);
@@ -2599,7 +2599,7 @@
     /* Must reference a field */
     CHECK_CP_TAG(op1u2, CONSTANT_Fieldref);
 
     /* calc clsidxmisc and pcpd and pcpd_Fieldref */
     CALCULATE_FIELD_INFO_FROM_FIELD_REFERENCE(op1u2);
 
     /* Must be a valid reference to a field */
@@ -2621,7 +2621,7 @@
             CHECK_FINAL_FIELD_CURRENT_CLASS;
 
             /* Store data into the static field now */
-            PUTDATA(CLASS(pcpd_Fieldref
+            PUTDATA(CLASS(pcpma_Fieldref
                             ->LOCAL_Fieldref_binding.clsidxJVM)
                     .class_static_field_data[fluidxmisc]);
             break;
@@ -2674,16 +2674,16 @@
     CHECK_CP_TAG(op1u2, CONSTANT_Methodref);
 
     /*
      * Calc clsidxmisc and pcpd and pcpd_Methodref.  If class
      * has not yet been loaded, do so now.  The spec says to
      * do it following the check for an abstract method, but
      * in this implementation, the loading has to be done
      * before the testing in case the method is not in this
      * class but in a superclass or superinterface.
      */
-    pcpd           = pcfs->constant_pool[op1u2];
-    pcpd_Methodref = PTR_THIS_CP_Methodref(pcpd);
-    clsidxmisc     = pcpd_Methodref->LOCAL_Methodref_binding.clsidxJVM;
+    pcpma           = pcfs->constant_pool[op1u2];
+    pcpma_Methodref = PTR_THIS_CP_Methodref(pcpma);
+    clsidxmisc      =pcpma_Methodref->LOCAL_Methodref_binding.clsidxJVM;
 
     /*
      * Try to resolve this class before attempting to load.
@@ -2696,15 +2696,15 @@
                                                              clsidx),
                                       rfalse);
 
-        clsidxmisc = pcpd_Methodref->LOCAL_Methodref_binding.clsidxJVM;
+        clsidxmisc = pcpma_Methodref->LOCAL_Methodref_binding.clsidxJVM;
 
         if (jvm_class_index_null == clsidxmisc)
         {
             /* If class is not loaded, retrieve it by UTF8 class name */
-            LATE_CLASS_LOAD(pcpd_Methodref->class_index);
+            LATE_CLASS_LOAD(pcpma_Methodref->class_index);
 
             /* Check if method exists in loaded class */
-            clsidxmisc = pcpd_Methodref
+            clsidxmisc = pcpma_Methodref
                            ->LOCAL_Methodref_binding.clsidxJVM;
             if (jvm_class_index_null == clsidxmisc)
             {
@@ -2716,7 +2716,7 @@
         }
     }
 
-    mthidxmisc = pcpd_Methodref->LOCAL_Methodref_binding.mthidxJVM;
+    mthidxmisc = pcpma_Methodref->LOCAL_Methodref_binding.mthidxJVM;
 
     if (jvm_method_index_bad == mthidxmisc)
     {
@@ -2733,7 +2733,7 @@
 
     /* Must be a valid reference to a method */
     if (jvm_attribute_index_bad == 
-        pcpd_Methodref->LOCAL_Methodref_binding.codeatridxJVM)
+        pcpma_Methodref->LOCAL_Methodref_binding.codeatridxJVM)
     {
         thread_throw_exception(thridx,
                                THREAD_STATUS_THREW_ERROR,
@@ -2832,7 +2832,7 @@
         /* Return code, if any, is pushed in the JNI processing code */
         native_run_method(thridx,
                           clsidxmisc,
-                          pcpd_Methodref
+                          pcpma_Methodref
                             ->LOCAL_Methodref_binding
                               .nmordJVM,
                           pmth->name_index,
@@ -3023,7 +3023,7 @@
     CHECK_NOT_ARRAY_OBJECT;
     CHECK_NOT_INTERFACE_CLASS;
 
     /* calc clsidxmisc and pcpd and pcpd_Class and pcfsmisc */
     CALCULATE_CLASS_INFO_FROM_CLASS_REFERENCE(op1u2);
 
     /* Create new object from this class */
@@ -3154,7 +3154,7 @@
     CHECK_CP_TAG(op1u2, CONSTANT_Class);
     /* CHECK_CP_TAG2/3(op1u2, CONSTANT_Class,array? ,interface? ); */
 
     /* calc clsidxmisc and pcpd and pcpd_Class and pcfsmisc */
     CALCULATE_CLASS_INFO_FROM_CLASS_REFERENCE(op1u2);
 
     /* Retrieve 'count' operand from TOS */
@@ -2544,7 +2544,7 @@
     CHECK_CP_TAG(op1u2, CONSTANT_Fieldref);
 
-    /* calc clsidxmisc and pcpd and pcpd_Fieldref */
+    /* calc clsidxmisc and pcpma and pcpma_Fieldref */
     CALCULATE_FIELD_INFO_FROM_FIELD_REFERENCE(op1u2);
 
@@ -2599,7 +2599,7 @@
     CHECK_CP_TAG(op1u2, CONSTANT_Fieldref);
 
-    /* calc clsidxmisc and pcpd and pcpd_Fieldref */
+    /* calc clsidxmisc and pcpma and pcpma_Fieldref */
     CALCULATE_FIELD_INFO_FROM_FIELD_REFERENCE(op1u2);
 
@@ -2674,16 +2674,16 @@
 
     /*
-     * Calc clsidxmisc and pcpd and pcpd_Methodref.  If class
+     * Calc clsidxmisc and pcpma and pcpma_Methodref.  If class
      * has not yet been loaded, do so now.  The spec says to
      * do it following the check for an abstract method, but
@@ -3023,7 +3023,7 @@
     CHECK_NOT_INTERFACE_CLASS;
 
-    /* calc clsidxmisc and pcpd and pcpd_Class and pcfsmisc */
+    /* calc clsidxmisc and pcpma and pcpma_Class and pcfsmisc */
     CALCULATE_CLASS_INFO_FROM_CLASS_REFERENCE(op1u2);
 
@@ -3154,7 +3154,7 @@
     /* CHECK_CP_TAG2/3(op1u2, CONSTANT_Class,array? ,interface? ); */
 
-    /* calc clsidxmisc and pcpd and pcpd_Class and pcfsmisc */
+    /* calc clsidxmisc and pcpma and pcpma_Class and pcfsmisc */
     CALCULATE_CLASS_INFO_FROM_CLASS_REFERENCE(op1u2);
 

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opmacros.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opmacros.h?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opmacros.h (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/opmacros.h Thu Apr 27 18:41:46 2006
@@ -588,7 +588,7 @@
  * <li> @c @e macro_expansion_of(data_array_slot)
  *                           Any @link #jvalue jvalue@endlink variable.
  * </li>
  * <li> @c @e pcpd_Fieldref  CONSTANT_Fieldref_info pointer to current
  *                           field
  * </li>
  * </ul>
@@ -618,7 +618,7 @@
  *
  */
 #define GETDATA(data_array_slot)                                       \
-    switch (pcpd_Fieldref->LOCAL_Fieldref_binding.jvaluetypeJVM)       \
+    switch (pcpma_Fieldref->LOCAL_Fieldref_binding.jvaluetypeJVM)      \
     {                                                                  \
         case BASETYPE_CHAR_B:                                          \
             PUSH(thridx,                                               \
@@ -725,7 +725,7 @@
  * <li> @c @e macro_expansion_of(data_array_slot)
  *                           Any @link #jvalue jvalue@endlink variable.
  * </li>
  * <li> @c @e pcpd_Fieldref  CONSTANT_Fieldref_info pointer to current
  *                           field
  * </li>
  * </ul>
@@ -755,7 +755,7 @@
  *
  */
 #define PUTDATA(data_array_slot)                                       \
-    switch (pcpd_Fieldref->LOCAL_Fieldref_binding.jvaluetypeJVM)       \
+    switch (pcpma_Fieldref->LOCAL_Fieldref_binding.jvaluetypeJVM)      \
     {                                                                  \
         case BASETYPE_CHAR_B:                                          \
             POP(thridx,                                                \
@@ -1288,9 +1288,9 @@
  * During the calculation, various scratch variables are
  * loaded and used to simplify the code.  Two final results
  * include a (CONSTANT_Class_info *) stored in the local variable
  * @b pcpd_Class stored the local variable @b pcfsmisc
  * and a (CONSTANT_Class_info *) stored in the local variable
- * @b pcpd_Class
+ * @b pcpma_Class
  *
  * @param clsnameidx  @c @b constant_pool index into class file of
  *                    current class (as indicated in the program
@@ -1311,12 +1311,12 @@
  *
  * <b>Local variables written:</b>
  * <ul>
  * <li> @c @e pcpd           pointer to a @c @b constant_pool entry
  * </li>
  * <li> @c @e pcpd_Class     @c @b pcpd as a CONSTANT_Class_info pointer
  * </li>
  * <li> @c @e clsidxmisc     Class index of fully bound class referenced
- *                           by @c @b pcpd_Class
+ *                           by @c @b pcpma_Class
  * </li>
  * <li>  @c @e pcfsmisc      @c @b pcfs class file field from class
  *                           referenced by @c @b clsidxmisc
@@ -1326,10 +1326,10 @@
  *
  */
 #define CALCULATE_CLASS_INFO_FROM_CLASS_REFERENCE(clsnameidx)          \
-    pcpd       = pcfs->constant_pool[clsnameidx];                      \
-    pcpd_Class = PTR_THIS_CP_Class(pcpd);                              \
+    pcpma       = pcfs->constant_pool[clsnameidx];                     \
+    pcpma_Class = PTR_THIS_CP_Class(pcpma);                            \
                                                                        \
-    clsidxmisc = pcpd_Class->LOCAL_Class_binding.clsidxJVM;            \
+    clsidxmisc = pcpma_Class->LOCAL_Class_binding.clsidxJVM;           \
                                                                        \
     /*                                                                 \
      * Try to resolve this class before attempting to load.            \
@@ -1342,7 +1342,7 @@
                                                              clsidx),  \
                                       rfalse);                         \
                                                                        \
-        clsidxmisc = pcpd_Class->LOCAL_Class_binding.clsidxJVM;        \
+        clsidxmisc = pcpma_Class->LOCAL_Class_binding.clsidxJVM;       \
                                                                        \
         /* Now try to load it again if resolution failed to locate it*/\
         if (jvm_class_index_null == clsidxmisc)                        \
@@ -1364,7 +1364,7 @@
  * loaded and used to simplify the code.  Two final results
  * include a (field_info *) stored the local variable @b pfld
  * and a (CONSTANT_Fieldref_info *) stored in the local variable
- * @b pcpd_Fieldref
+ * @b pcpma_Fieldref
  *
  * @param Fieldref  @c @b constant_pool index into class file of current
  *                  class (as indicated in the program counter) that
@@ -1389,19 +1389,19 @@
  *
  * <b>Local variables written:</b>
  * <ul>
  * <li> @c @e pcpd           pointer to a @c @b constant_pool entry
  * </li>
- * <li> @c @e pcpd_Fieldref @c @b pcpd as a CONSTANT_Fieldref_info
+ * <li> @c @e pcpma_Fieldref @c @b pcpma as a CONSTANT_Fieldref_info
  *                           pointer
  * </li>
  * <li> @c @e clsidxmisc     Class index of fully bound class referenced
- *                           by @c @b pcpd_Fieldref
+ *                           by @c @b pcpma_Fieldref
  * </li>
  * <li>  @c @e pcfsmisc      @c @b pcfs class file field from class
  *                           referenced by @c @b clsidxmisc
  * </li>
  * <li>  @c @e pfld          field_info table entry referenced by
- *                           @c @b pcpd_Fieldref
+ *                           @c @b pcpma_Fieldref
  * </li>
  * <li>  @c @e fluidxmisc    Field lookup index of field from class
  *                           referenced by @c @b clsidxmisc
@@ -1415,9 +1415,9 @@
  *
  */
 #define CALCULATE_FIELD_INFO_FROM_FIELD_REFERENCE(Fieldref)            \
-    pcpd           = pcfs->constant_pool[Fieldref];                    \
-    pcpd_Fieldref = PTR_THIS_CP_Fieldref(pcpd);                        \
-    clsidxmisc     = pcpd_Fieldref->LOCAL_Fieldref_binding.clsidxJVM;  \
+    pcpma           = pcfs->constant_pool[Fieldref];                   \
+    pcpma_Fieldref = PTR_THIS_CP_Fieldref(pcpma);                      \
+    clsidxmisc     = pcpma_Fieldref->LOCAL_Fieldref_binding.clsidxJVM; \
                                                                        \
     /*                                                                 \
      * Try to resolve this class before attempting to load.            \
@@ -1430,16 +1430,16 @@
                                                              clsidx),  \
                                       rfalse);                         \
                                                                        \
-        clsidxmisc = pcpd_Fieldref->LOCAL_Fieldref_binding.clsidxJVM;  \
+        clsidxmisc = pcpma_Fieldref->LOCAL_Fieldref_binding.clsidxJVM; \
                                                                        \
         /* Now try to load it again if resolution failed to locate it*/\
         if (jvm_class_index_null == clsidxmisc)                        \
         {                                                              \
             /* If class is not loaded, retrieve it by UTF8 class name*/\
-            LATE_CLASS_LOAD(pcpd_Fieldref->class_index);               \
+            LATE_CLASS_LOAD(pcpma_Fieldref->class_index);              \
                                                                        \
             /* Check if field exists in loaded class */                \
-            clsidxmisc = pcpd_Fieldref                                 \
+            clsidxmisc = pcpma_Fieldref                                \
                            ->LOCAL_Fieldref_binding.clsidxJVM;         \
             if (jvm_class_index_null == clsidxmisc)                    \
             {                                                          \
@@ -1451,7 +1451,7 @@
         }                                                              \
     }                                                                  \
                                                                        \
-    fluidxmisc     = pcpd_Fieldref->LOCAL_Fieldref_binding.fluidxJVM;  \
+    fluidxmisc     = pcpma_Fieldref->LOCAL_Fieldref_binding.fluidxJVM; \
     if (jvm_field_index_bad == fluidxmisc)                             \
     {                                                                  \
         thread_throw_exception(thridx,                                 \
@@ -1461,7 +1461,7 @@
     }                                                                  \
                                                                        \
     pcfsmisc       = CLASS_OBJECT_LINKAGE(clsidxmisc)->pcfs;           \
-    fluidxmisc     = pcpd_Fieldref->LOCAL_Fieldref_binding.fluidxJVM;  \
+    fluidxmisc     = pcpma_Fieldref->LOCAL_Fieldref_binding.fluidxJVM; \
     pfld           = pcfsmisc                                          \
                        ->fields[CLASS(clsidxmisc)                      \
                                  .class_static_field_lookup[fluidxmisc]]
@@ -1536,13 +1536,13 @@
  *
  * <b>Local variables written:</b>
  * <ul>
  * <li> @c @e pcpd           pointer to a @c @b constant_pool entry,
  *                           ultimately pointing to the entry containing
  *                           the name of the input @c @b clsnameidx
  * </li>
  * <li> @c @e pcpd_Class     @c @b pcpd as a CONSTANT_Class_info pointer
  * </li>
  * <li> @c @e pcpd_Utf8      @c @b pcpd as a CONSTANT_Utf8_info pointer
  * </li>
  * <li> @c @e prchar_clsname Null-terminated string version of class
  *                           name @c @b clsnameidx
@@ -1560,13 +1560,13 @@
  */
 #define LATE_CLASS_LOAD(clsnameidx)                                  \
                                                                      \
-    pcpd       = pcfs->constant_pool[clsnameidx]; /* Class name */   \
-    pcpd_Class = PTR_THIS_CP_Class(pcpd);                            \
+    pcpma       = pcfs->constant_pool[clsnameidx]; /* Class name */  \
+    pcpma_Class = PTR_THIS_CP_Class(pcpma);                          \
                                                   /* UTF8 string */  \
-    pcpd       = pcfs->constant_pool[pcpd_Class->name_index];        \
-    pcpd_Utf8  = PTR_THIS_CP_Utf8(pcpd);                             \
+    pcpma       = pcfs->constant_pool[pcpma_Class->name_index];      \
+    pcpma_Utf8  = PTR_THIS_CP_Utf8(pcpma);                           \
                                                                      \
-    prchar_clsname = utf_utf2prchar(pcpd_Utf8);                      \
+    prchar_clsname = utf_utf2prchar(pcpma_Utf8);                     \
                                                                      \
     /* Try again to load class */                                    \
     clsidxmisc = class_load_resolve_clinit(prchar_clsname,           \
@@ -1907,7 +1907,7 @@
  *                           (input parameter to
  *                           @link #opcode_run opcode_run()@endlink)
  * </li>
  * <li> @c @e pcpd_Fieldref  CONSTANT_Fieldref_info pointer to current
  *                           field
  * </li>
  * <li>  @c @e pfld          field_info table entry of current field
@@ -1932,7 +1932,7 @@
                                                                  \
         /* A final field must _not_ be found in a superclass */  \
         if ((ACC_FINAL & pfld->access_flags) &&                  \
-            (clsidxTMP != pcpd_Fieldref                          \
+            (clsidxTMP != pcpma_Fieldref                         \
                             ->LOCAL_Fieldref_binding.clsidxJVM)) \
         {                                                        \
             thread_throw_exception(thridx,                       \
@@ -588,7 +588,7 @@
  *                           Any @link #jvalue jvalue@endlink variable.
  * </li>
- * <li> @c @e pcpd_Fieldref  CONSTANT_Fieldref_info pointer to current
+ * <li> @c @e pcpma_Fieldref CONSTANT_Fieldref_info pointer to current
  *                           field
  * </li>
@@ -725,7 +725,7 @@
  *                           Any @link #jvalue jvalue@endlink variable.
  * </li>
- * <li> @c @e pcpd_Fieldref  CONSTANT_Fieldref_info pointer to current
+ * <li> @c @e pcpma_Fieldref CONSTANT_Fieldref_info pointer to current
  *                           field
  * </li>
@@ -1288,9 +1288,9 @@
  * loaded and used to simplify the code.  Two final results
  * include a (CONSTANT_Class_info *) stored in the local variable
- * @b pcpd_Class stored the local variable @b pcfsmisc
+ * @b pcpma_Class stored the local variable @b pcfsmisc
  * and a (CONSTANT_Class_info *) stored in the local variable
@@ -1311,12 +1311,12 @@
  * <b>Local variables written:</b>
  * <ul>
- * <li> @c @e pcpd           pointer to a @c @b constant_pool entry
+ * <li> @c @e pcpma          pointer to a @c @b constant_pool entry
  * </li>
@@ -1311,12 +1311,12 @@
  * </li>
- * <li> @c @e pcpd_Class     @c @b pcpd as a CONSTANT_Class_info pointer
+ * <li> @c @e pcpma_Class   @c @b pcpma as a CONSTANT_Class_info pointer
  * </li>
  * <li> @c @e clsidxmisc     Class index of fully bound class referenced
@@ -1389,19 +1389,19 @@
  * <b>Local variables written:</b>
  * <ul>
- * <li> @c @e pcpd           pointer to a @c @b constant_pool entry
+ * <li> @c @e pcpma          pointer to a @c @b constant_pool entry
  * </li>
@@ -1536,13 +1536,13 @@
  * <b>Local variables written:</b>
  * <ul>
- * <li> @c @e pcpd           pointer to a @c @b constant_pool entry,
+ * <li> @c @e pcpma          pointer to a @c @b constant_pool entry,
  *                           ultimately pointing to the entry containing
  *                           the name of the input @c @b clsnameidx
@@ -1536,13 +1536,13 @@
  *                           the name of the input @c @b clsnameidx
  * </li>
- * <li> @c @e pcpd_Class     @c @b pcpd as a CONSTANT_Class_info pointer
+ * <li> @c @e pcpma_Class   @c @b pcpma as a CONSTANT_Class_info pointer
  * </li>
@@ -1536,13 +1536,13 @@
  * </li>
- * <li> @c @e pcpd_Utf8      @c @b pcpd as a CONSTANT_Utf8_info pointer
+ * <li> @c @e pcpma_Utf8     @c @b pcpma as a CONSTANT_Utf8_info pointer
  * </li>
  * <li> @c @e prchar_clsname Null-terminated string version of class
@@ -1907,7 +1907,7 @@
  *                           @link #opcode_run opcode_run()@endlink)
  * </li>
- * <li> @c @e pcpd_Fieldref  CONSTANT_Fieldref_info pointer to current
+ * <li> @c @e pcpma_Fieldref CONSTANT_Fieldref_info pointer to current
  *                           field
  * </li>

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.c
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.c?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================
--- incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.c (original)
+++ incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.c Thu Apr 27 18:41:46 2006
@@ -79,7 +79,7 @@
  *
  *
  * @returns UTF8 structure containing length and character buffer (plus
  *          tag), but return in (cp_info_dup) for full proper word
  *          alignment. When done with the data, call HEAP_FREE_DATA()
  *          on it.
  *
@@ -93,7 +93,7 @@
  *                        than that.
  */
 
-cp_info_dup *unicode_cnv2utf(jchar *inbfr, jshort length)
+cp_info_mem_align *unicode_cnv2utf(jchar *inbfr, jshort length)
 {
     ARCH_FUNCTION_NAME(unicode_cnv2utf);
 
@@ -162,12 +162,12 @@
      * info, adjusting for the amount of string data to be stored
      * into the result.
      */
-    cp_info_dup *rc = HEAP_GET_DATA(sizeof(cp_info_dup) -
-                                        sizeof(cp_info) +
-                                        sizeof(CONSTANT_Utf8_info) -
-                                        sizeof(u1) +
-                                        bytecnvcount,
-                                    rfalse);
+    cp_info_mem_align *rc = HEAP_GET_DATA(sizeof(cp_info_mem_align) -
+                                              sizeof(cp_info) +
+                                            sizeof(CONSTANT_Utf8_info) -
+                                              sizeof(u1) +
+                                              bytecnvcount,
+                                          rfalse);
 
     /* Prepare output structure with everything but character cnv */
     CONSTANT_Utf8_info *pcpui = PTR_THIS_CP_Utf8(rc);
@@ -79,7 +79,7 @@
  *
  * @returns UTF8 structure containing length and character buffer (plus
- *          tag), but return in (cp_info_dup) for full proper word
+ *          tag), but return in (cp_info_mem_align) for full proper word
  *          alignment. When done with the data, call HEAP_FREE_DATA()
  *          on it.

Modified: incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.h
URL: http://svn.apache.org/viewcvs/incubator/harmony/enhanced/trunk/sandbox/contribs/bootjvm/bootJVM/jvm/src/unicode.h?rev=397712&r1=397711&r2=397712&view=diff
==============================================================================